# ragtag

**DOI:** [10.5281/zenodo.13759600](https://doi.org/10.5281/zenodo.13759600)

## Available Versions
- **Version 2.1.0**
  - [Download](https://zenodo.org/record/13759601/files/ragtag_2.1.0.img)
  - **MD5:** `a4b9825b45e158b5ee7402e98056b59f`
  - **DOI:** [10.5281/zenodo.13759601](https://doi.org/10.5281/zenodo.13759601)
  - **Size:** 188.94 MB
  - **Binaries:** 0 available

## Binaries (17 total)

```ragtag.py ragtag_agp2fa.py ragtag_correct.py ragtag_paf2delta.py ragtag_scaffold.py ragtag_agpcheck.py ragtag_create_links.py ragtag_patch.py ragtag_splitasm.py ragtag_asmstats.py ragtag_delta2paf.py ragtag.py ragtag_stats.py ragtag_break_query.py ragtag_merge.py ragtag_rename.py ragtag_update_gff.py```
